@@ -54,9 +54,13 @@ class AnyscaleJob(Infrastructure):
 
         cmd += " /home/ray/anaconda3/bin/python -m prefect.engine"
 
+        # Link the Job on the Anyscale UI with the prefect flow run
+        job_name = "prefect-job-" + flow_run_id
+
         content = """
+        name: "{}"
         entrypoint: "{}"
-        """.format(cmd)
+        """.format(job_name, cmd)
 
         if self.compute_config:
             content += 'compute_config: "{}"\n'.format(self.compute_config)
@@ -70,6 +74,9 @@ class AnyscaleJob(Infrastructure):
             logging.info(f"Submitting Anyscale Job with configuration '{content}'")
             returncode = subprocess.check_call(["anyscale", "job", "submit", f.name])
 
+        if task_status:
+            task_status.started(job_name)
+
         return AnyscaleJobResult(
             status_code=returncode, identifier=""
         )
@@ -85,3 +92,4 @@ class AnyscaleJob(Infrastructure):
 
 class AnyscaleJobResult(InfrastructureResult):
     """Contains information about the final state of a completed process"""
+    pass
